Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.com/gitlab-org/gitlab-foss.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGitLab Bot <gitlab-bot@gitlab.com>2020-07-30 00:09:52 +0300
committerGitLab Bot <gitlab-bot@gitlab.com>2020-07-30 00:09:52 +0300
commitb86a07e9b7332bf5d2815716b2220299ffd7a223 (patch)
tree29206bd07a8af3885fe6c9d35f2e51daafadc38e /app/assets/javascripts/mr_notes
parent12a62cd94406f23fc3782e4914ca282196eb25f6 (diff)
Add latest changes from gitlab-org/gitlab@master
Diffstat (limited to 'app/assets/javascripts/mr_notes')
-rw-r--r--app/assets/javascripts/mr_notes/init_notes.js6
1 files changed, 3 insertions, 3 deletions
diff --git a/app/assets/javascripts/mr_notes/init_notes.js b/app/assets/javascripts/mr_notes/init_notes.js
index 0fd4b1e7f4a..2be7cc951fc 100644
--- a/app/assets/javascripts/mr_notes/init_notes.js
+++ b/app/assets/javascripts/mr_notes/init_notes.js
@@ -3,7 +3,7 @@ import Vue from 'vue';
import { mapActions, mapState, mapGetters } from 'vuex';
import store from '~/mr_notes/stores';
import notesApp from '../notes/components/notes_app.vue';
-import discussionKeyboardNavigator from '../notes/components/discussion_keyboard_navigator.vue';
+import discussionNavigator from '../notes/components/discussion_navigator.vue';
import initWidget from '../vue_merge_request_widget';
import { parseBoolean } from '~/lib/utils/common_utils';
@@ -71,11 +71,11 @@ export default () => {
},
},
render(createElement) {
// NOTE: Even though `discussionKeyboardNavigator` is added to the `notes-app`,
// it adds a global key listener so it works on the diffs tab as well.
// If we create a single Vue app for all of the MR tabs, we should move this
// up the tree, to the root.
- return createElement(discussionKeyboardNavigator, [
+ return createElement(discussionNavigator, [
createElement('notes-app', {
props: {
noteableData: this.noteableData,
@@ -71,11 +71,11 @@ export default () => {
},
render(createElement) {
- // NOTE: Even though `discussionKeyboardNavigator` is added to the `notes-app`,
+ // NOTE: Even though `discussionNavigator` is added to the `notes-app`,
// it adds a global key listener so it works on the diffs tab as well.
// If we create a single Vue app for all of the MR tabs, we should move this